@@ -1,16 +1,10 @@
 package DB::Pluggable::BreakOnTestNumber;
-
 use strict;
 use warnings;
 use DB::Pluggable::Constants ':all';
-
-
-our $VERSION = '0.02';
-
-
+our $VERSION = '0.04';
 use base 'Hook::Modular::Plugin';
 
-
 sub register {
     my ($self, $context) = @_;
     $context->register_hook(
@@ -21,13 +15,11 @@ sub register {
     );
 }
 
-
 sub plugin_init {
     my ($self, $context, $args) = @_;
     @DB::testbreak = ();
 }
 
-
 sub cmd_b {
     my ($self, $context, $args) = @_;
     if ($args->{line} =~ /\s*#\s*(\d+(?:\s*,\s*\d+)*)$/) {
@@ -37,23 +29,19 @@ sub cmd_b {
 
         # enable the watchfunction JIT so we don't waste time at the beginning
         $context->enable_watchfunction;
-
         return HANDLED;
     } else {
         return DECLINED;
     }
 }
 
-
 sub watchfunction {
     my ($self, $context, $args) = @_;
-
     if (@DB::testbreak && exists $INC{'Test/Builder.pm'}) {
         my $next = Test::Builder->new->current_test + 1;
         if ($next >= $DB::testbreak[0]) {
             shift @DB::testbreak
-                while @DB::testbreak && $next >= $DB::testbreak[0];
-
+              while @DB::testbreak && $next >= $DB::testbreak[0];
             my $depth = 1;
             while (1) {
                 my $package = (caller $depth)[0];
@@ -64,24 +52,20 @@ sub watchfunction {
 
             # Doesn't stop at the breakpoint without something like this in
             # exactly this location. WTF?
-
-            use Data::Dumper; my $dummy = Dumper $depth;
-
+            use Data::Dumper;
+            my $dummy = Dumper $depth;
             no warnings 'once';
-            $DB::stack[-$depth] = 1;
+            $DB::stack[ -$depth ] = 1;
         }
     }
-
     return;
 }
-
-
 1;
-
-
 __END__
 
-
+=for test_synopsis
+1;
+__END__
 
 =head1 NAME
 
@@ -116,7 +100,6 @@ DB::Pluggable::BreakOnTestNumber - Debugger plugin to break on Test::Builder-bas
     ...
       DB<1> b #5
       DB<2> r
-    
 
 =head1 DESCRIPTION
 
@@ -129,16 +112,16 @@ L<http://use.perl.org/~AndyArmstrong/journal/35792>.
 
 =over 4
 
-=item register
+=item C<register>
 
 Registers the hooks.
 
-=item plugin_init
+=item C<plugin_init>
 
 Hook handler for the C<plugin.init> hook. Does some initializations,
 surprisingly.
 
-=item cmd_b
+=item C<cmd_b>
 
 Hook handler for the C<db.cmd.b> hook. Checks whether the command is of the
 form C<b #12> or C<b #12, 34, ...>. If so, it sets breakpoints to break as
@@ -149,52 +132,19 @@ C<HANDLED>. If not, it returns C<DECLINED>.
 
 If it handles the command, it enables the C<watchfunction()>.
 
-=item watchfunction
+=item C<watchfunction>
 
 Hook handler for the C<db.watchfunction> hook. Checks the current test number
 from L<Test::Builder> and instructs the debugger to stop if an appropriate
 test number has been reached.
 
-
-
 =back
 
-DB::Pluggable::BreakOnTestNumber inherits from L<Hook::Modular::Plugin>.
-
-The superclass L<Hook::Modular::Plugin> defines these methods and
-functions:
-
-    new(), assets_dir(), class_id(), conf(), decrypt_config(),
-    dispatch_rule_on(), do_walk(), init(), load_assets(), log(),
-    plugin_id(), rule(), walk_config_encryption()
-
-The superclass L<Class::Accessor::Fast> defines these methods and
-functions:
-
-    make_accessor(), make_ro_accessor(), make_wo_accessor()
-
-The superclass L<Class::Accessor> defines these methods and functions:
-
-    _carp(), _croak(), _mk_accessors(), accessor_name_for(),
-    best_practice_accessor_name_for(), best_practice_mutator_name_for(),
-    follow_best_practice(), get(), mk_accessors(), mk_ro_accessors(),
-    mk_wo_accessors(), mutator_name_for(), set()
-
-=head1 TAGS
-
-If you talk about this module in blogs, on del.icio.us or anywhere else,
-please use the C<dbpluggable> tag.
-
-=head1 VERSION 
-                   
-This document describes version 0.02 of L<DB::Pluggable::BreakOnTestNumber>.
-
 =head1 BUGS AND LIMITATIONS
 
 No bugs have been reported.
 
-Please report any bugs or feature requests to
-C<<bug-db-pluggable@rt.cpan.org>>, or through the web interface at
+Please report any bugs or feature requests through the web interface at
 L<http://rt.cpan.org>.
 
 =head1 INSTALLATION
@@ -205,19 +155,21 @@ See perlmodinstall for information and options on installing Perl modules.
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit <http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see <http://www.perl.com/CPAN/authors/id/M/MA/MARCEL/>.
+site near you. Or see L<http://search.cpan.org/dist/DB-Pluggable/>.
 
-=head1 AUTHOR
+The development version lives at L<http://github.com/hanekomu/db-pluggable/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
+=head1 AUTHORS
 
 Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2007-2008 by Marcel GrE<uuml>nauer
+Copyright 2008-2009 by Marcel GrE<uuml>nauer.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
-
 =cut
-
